isotoma.django.bootstrap
------------------------

The aim of this code is to be able to bootstrap a Django project, in egg format,
using the Isotoma standard directories and settings files.

This can be dropped into a Django buildout, used to create a project in development mode,
and then removed in a production environment.